pub trait IntoBody: Body { // Required method fn into_body(self) -> Result<Vec<u8>>; }
Implemented by the Reply::body to convert itself into a format compatible with [IntoResponse].
Reply::body
[IntoResponse]
Convert implementing type into an http-compatible body.
Returns an error if the body cannot be encoded (for example, if JSON serialization fails).